﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System.Windows.Data;

namespace ScheduleAuditMgmt
{
    public class AllScheduledAuditViewModel : INotifyPropertyChanged
    {
        private List<ScheduleAuditInfoViewModel> _audits;
        private ICollectionView _availableAuditsView;
        private string _selectedAudit;

        public AllScheduledAuditViewModel()
        {            
            AuditTypes = new ObservableCollection<string> { "Equipment", "Application", "Inventory" };
            _availableAuditsView = CollectionViewSource.GetDefaultView(AuditTypes);
            _availableAuditsView.CurrentChanged += new EventHandler(OnAuditTypeChanged);                        
        }

        public List<ScheduleAuditInfoViewModel> Audits 
        {
            get { return _audits; }
            set
            {
                _audits = value;

                OnPropertyChanged("Audits");
            }
        }

        public ObservableCollection<string> AuditTypes
        {
            get;
            private set;
        }

        public ICollectionView AvailableAuditsView
        {
            get
            {
                return _availableAuditsView;
            }
        }

        void OnAuditTypeChanged(object sender, EventArgs e)
        {            
            _selectedAudit = _availableAuditsView.CurrentItem as string;


            // Filter and then display
            List<ScheduleAuditInfoViewModel> audits =
                (from audit in ScheduledAuditInfo.GetScheduledAuditInfo(_selectedAudit)
                 select new ScheduleAuditInfoViewModel(audit))
                .ToList();

            this.Audits = audits;
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        void OnPropertyChanged(string prop)
        {
            if (this.PropertyChanged != null)
                this.PropertyChanged(this, new PropertyChangedEventArgs(prop));
        }

        #endregion
    }

    
}
