﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml.Linq;
using System.Collections.ObjectModel;

namespace ScheduleAuditMgmt
{
    public class ScheduledAuditInfo
    {
        public ScheduledAuditInfo()
        {
            
        }

        public static ScheduledAuditInfo[] GetScheduledAuditInfo(string filter)
        {
            ScheduledAuditInfo[] info = null;

            // Read from Xml for the time being and later make an WCF call to retrieve this Info
            XElement document = XElement.Load(@"C:\ASNC\ScheduleAuditMgmt\ScheduleAuditMgmt\ScheduleInfo.xml");

            var scheduledAuditInfo =
                from scheduleAuditInfo in document.Elements("ORA_TABLE")
                where scheduleAuditInfo.Element("AUDITTYPE").Value == filter
                select scheduleAuditInfo;

            int scheduledAuditCount = scheduledAuditInfo.Count();
            info = new ScheduledAuditInfo[scheduledAuditCount];

            int rowCount = -1;

            foreach (XElement scheduledAuditInst in scheduledAuditInfo)
            {
                rowCount++;
                info[rowCount] = new ScheduledAuditInfo();

                foreach (XElement field in scheduledAuditInst.Descendants())
                {
                    string fieldName = field.Name.ToString();
                    string fieldVal = field.Value;

                    switch (fieldName)
                    {
                        case "AUDITID":
                            int id = Int32.Parse(fieldVal);
                            info[rowCount].AuditId = id;
                            break;
                        case "AUDITTYPE":
                            info[rowCount].AuditType = fieldVal;
                            break;
                        case "AUDITCREATOR":
                            info[rowCount].AuditCreator = fieldVal;
                            break;
                        case "AUDITDESCRIPTION":
                            info[rowCount].AuditDescription = fieldVal;
                            break;
                        case "SITE":
                            info[rowCount].Site = fieldVal;
                            break;
                        case "AUDITINITIATEDDATE":
                            info[rowCount].AuditInitiatedDate = fieldVal;
                            break;
                        case "EMAIL":
                            ObservableCollection<Email> emailIds = null;

                            SetEmailIds(fieldVal, out emailIds);
                            info[rowCount].EmailIds = emailIds;
                            break;
                        case "AUDITSCHEDULEDDATETIME":
                            DateTime date = default(DateTime);
                            string time = default(string);

                            SetAuditScheduledDateAndTime(fieldVal, out date, out time);
                            info[rowCount].AuditScheduledDate = date;
                            info[rowCount].AuditScheduledTime = time;
                            break;
                        case "OFFSETINHOURS":
                            info[rowCount].OffsetInHours = Int32.Parse(fieldVal);
                            break;
                        case "NUMBEROFAUDITOCCURRENCES":
                            int numOcc = Int32.Parse(fieldVal);

                            info[rowCount].NumOccurences = numOcc;
                            break;
                        case "ISSCHEDULEDAUDIT":
                            char isScheduled = fieldVal[0];

                            info[rowCount].IsScheduledAudit = isScheduled;
                            break;
                    }


                }
            }


            return info;
        }

        private static void SetEmailIds(string fieldVal, out ObservableCollection<Email> emailIds)
        {
            emailIds = new ObservableCollection<Email>();

            string[] allEmails = fieldVal.Split(new char[] { ';'},StringSplitOptions.RemoveEmptyEntries);

            foreach (string email in allEmails)
                emailIds.Add(new Email { Id = email } );

        }

        private static void SetAuditScheduledDateAndTime(string fieldVal, out DateTime date, out string time)
        {
            string[] dateAndTime = fieldVal.Split(new char[] { ' ' },StringSplitOptions.RemoveEmptyEntries);
            const int DATE = 0;
            const int TIME = 1;

            date = DateTime.Parse(dateAndTime[DATE]);
            time = dateAndTime[TIME];
        }

        public int AuditId { get; private set; }
        public string AuditType { get; private set; }
        public string AuditCreator { get; private set; }
        public string AuditDescription { get; private set; }
        public string Site { get; private set; }
        public string AuditInitiatedDate { get; private set; }        
        public ObservableCollection<Email> EmailIds { get; set; }
        public DateTime AuditScheduledDate { get; set; }
        public string AuditScheduledTime { get; set; }
        public int OffsetInHours { get; set; }
        public int NumOccurences { get; set; }
        public char IsScheduledAudit { get; set; }
    }

    public class Email
    {
        public string Id { get; set; }
    }
}
